@@ -1,5 +1,5 @@
 from volworld_common.util.id_util import new_rand_test_user_name, rand_test_id
-from volsite_postgres_common.test.behave.BehaveUtil import BehaveUtil
+from volworld_common.test.behave.BehaveUtil import BehaveUtil
 
 class UserInfo:
     def __init__(self, name: str, password: str = None):
